==> coin2_2.3.0.orig.tar.gz: Coin-2.3.0/include/Inventor/elements/SoGLMultiTextureEnabledElement.h <==
#ifndef COIN_SOGLMULTITEXTUREENABLEDELEMENT_H
#define COIN_SOGLMULTITEXTUREENABLEDELEMENT_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#include <Inventor/elements/SoMultiTextureEnabledElement.h>

typedef struct cc_glglue cc_glglue;

class COIN_DLL_API SoGLMultiTextureEnabledElement : public SoMultiTextureEnabledElement {
  typedef SoMultiTextureEnabledElement inherited;

  SO_ELEMENT_HEADER(SoGLMultiTextureEnabledElement);
public:
  static void initClass(void);
protected:
  virtual ~SoGLMultiTextureEnabledElement();

public:
  virtual void init(SoState * state);

  virtual void push(SoState * state);
  virtual void pop(SoState * state,
                   const SoElement * prevTopElement);
  virtual void setElt(const int unit, const SbBool onoff);

private:
  void updategl(const int unit);
  const cc_glglue * glue;
};

#endif // !COIN_SOGLMULTITEXTUREENABLEDELEMENT_H

==> coin2_2.4.4.orig.tar.gz: Coin-2.4.4/include/Inventor/elements/SoGLMultiTextureEnabledElement.h <==
#ifndef COIN_SOGLMULTITEXTUREENABLEDELEMENT_H
#define COIN_SOGLMULTITEXTUREENABLEDELEMENT_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#include <Inventor/elements/SoMultiTextureEnabledElement.h>

typedef struct cc_glglue cc_glglue;

class COIN_DLL_API SoGLMultiTextureEnabledElement : public SoMultiTextureEnabledElement {
  typedef SoMultiTextureEnabledElement inherited;

  SO_ELEMENT_HEADER(SoGLMultiTextureEnabledElement);
public:
  static void initClass(void);
protected:
  virtual ~SoGLMultiTextureEnabledElement();

public:
  virtual void init(SoState * state);

  virtual void push(SoState * state);
  virtual void pop(SoState * state,
                   const SoElement * prevTopElement);
  virtual void setElt(const int unit, const SbBool onoff);

private:
  void updategl(const int unit);
  void updategl(const int unit, const Mode oldvalue, const Mode newvalue);
  const cc_glglue * glue;
};

#endif // !COIN_SOGLMULTITEXTUREENABLEDELEMENT_H
